@@ -1,14 +1,24 @@
 
+from copy import deepcopy
+
 from django.contrib import admin
 
-from mezzanine.blog.models import BlogPost, Comment
+from mezzanine.blog.models import BlogPost, BlogCategory, Comment
 from mezzanine.core.admin import DisplayableAdmin, OwnableAdmin
 from mezzanine.settings import COMMENTS_DISQUS_SHORTNAME
 
 
+blogpost_fieldsets = deepcopy(DisplayableAdmin.fieldsets)
+blogpost_fieldsets[0][1]["fields"].insert(1, "category")
+blogpost_radio_fields = deepcopy(DisplayableAdmin.radio_fields)
+blogpost_radio_fields["category"] = admin.HORIZONTAL
+
+
 class BlogPostAdmin(DisplayableAdmin, OwnableAdmin):
 
+    fieldsets = blogpost_fieldsets
     list_display = ("title", "user", "status", "admin_link")
+    radio_fields = blogpost_radio_fields
 
     def save_form(self, request, form, change):
         """
@@ -18,6 +28,10 @@ class BlogPostAdmin(DisplayableAdmin, OwnableAdmin):
         return DisplayableAdmin.save_form(self, request, form, change)
 
 
+class BlogCategoryAdmin(admin.ModelAdmin):
+    fieldsets = ((None, {"fields": ("title",)}),)
+
+
 class CommentAdmin(admin.ModelAdmin):
 
     list_display = ("avatar_link", "intro", "time_created", "approved",
@@ -34,5 +48,6 @@ class CommentAdmin(admin.ModelAdmin):
     )
 
 admin.site.register(BlogPost, BlogPostAdmin)
+admin.site.register(BlogCategory, BlogCategoryAdmin)
 if not COMMENTS_DISQUS_SHORTNAME:
     admin.site.register(Comment, CommentAdmin)
