@@ -11,7 +11,8 @@ from django.template.loader import select_template
 from django.core.urlresolvers import reverse
 
 from mezzanine.blog.forms import CommentForm
-from mezzanine.blog.models import BlogPost
+from mezzanine.blog.models import BlogPost, BlogCategory
+from mezzanine.core.models import Keyword
 from mezzanine.pages.models import Page
 from mezzanine.utils import paginate
 from mezzanine import settings as blog_settings
@@ -21,19 +22,23 @@ use_disqus = bool(blog_settings.COMMENTS_DISQUS_SHORTNAME)
 
 
 def blog_post_list(request, tag=None, year=None, month=None, username=None,
-    template="blog/blog_post_list.html"):
+    category=None, template="blog/blog_post_list.html"):
     """
     Display a list of blog posts.
     """
     blog_posts = BlogPost.objects.published(for_user=request.user).annotate(
         num_comments=Count("comments"))
     if tag is not None:
-        blog_posts = blog_posts.filter(keywords__value=tag)
+        tag = get_object_or_404(Keyword, slug=tag)
+        blog_posts = blog_posts.filter(keywords=tag)
     if year is not None:
         blog_posts = blog_posts.filter(publish_date__year=year)
         if month is not None:
             blog_posts = blog_posts.filter(publish_date__month=month)
             month = month_name[int(month)]
+    if category is not None:
+        category = get_object_or_404(BlogCategory, slug=category)
+        blog_posts = blog_posts.filter(category=category)
     user = None
     if username is not None:
         user = get_object_or_404(User, username=username)
@@ -41,8 +46,8 @@ def blog_post_list(request, tag=None, year=None, month=None, username=None,
     blog_posts = paginate(blog_posts, request.GET.get("page", 1),
         blog_settings.BLOG_POST_PER_PAGE,
         blog_settings.BLOG_POST_MAX_PAGING_LINKS)
-    context = {"blog_posts": blog_posts, "year": year, "month": month,
-        "tag": tag, "user": user, "use_disqus": use_disqus}
+    context = {"blog_posts": blog_posts, "year": year, "month": month, "tag": 
+        tag, "category": category, "user": user, "use_disqus": use_disqus}
     return render_to_response(template, context, RequestContext(request))
 
 
