@@ -42,8 +42,8 @@ class DisplayableAdmin(admin.ModelAdmin):
     date_hierarchy = "publish_date"
     radio_fields = {"status": admin.HORIZONTAL}
     fieldsets = (
-        (None, {"fields": ("title", "status", ("publish_date", "expiry_date"), 
-            "content")}),
+        (None, {"fields": ["title", "status", ("publish_date", "expiry_date"), 
+            "content"]}),
         (_("Meta data"), {"fields": ("slug", "description", "keywords"),
             "classes": ("collapse-closed",)},),
     )
