@@ -14,6 +14,8 @@ class Page(Orderable, Displayable):
 
     parent = models.ForeignKey("Page", blank=True, null=True,
         related_name="children")
+    in_navigation = models.BooleanField(_("Show in navigation"), default=True)
+    in_footer = models.BooleanField(_("Show in footer"))
     titles = models.CharField(editable=False, max_length=1000, null=True)
     content_model = models.CharField(editable=False, max_length=50, null=True)
     login_required = models.BooleanField(_("Login required"), 
