@@ -30,6 +30,7 @@ def _page_menu(context, parent_page):
             except KeyError:
                 slug = ""
             setattr(page, "selected", slug.startswith(page.slug))
+            setattr(page, "primary", page.parent_id is None)
             pages[page.parent_id].append(page)
         context["menu_pages"] = pages
     if parent_page is not None:
@@ -50,7 +51,15 @@ def tree_menu(context, parent_page=None):
 @register.inclusion_tag("pages/includes/primary_menu.html", takes_context=True)
 def primary_menu(context, parent_page=None):
     """
-    Page menu that only renders the primary top-level pages..
+    Page menu that only renders the primary top-level pages.
+    """
+    return _page_menu(context, parent_page)
+
+
+@register.inclusion_tag("pages/includes/footer_menu.html", takes_context=True)
+def footer_menu(context, parent_page=None):
+    """
+    Page menu that only renders the footer pages.
     """
     return _page_menu(context, parent_page)
 
